Customer class

Represents the customer making the payment.

Constructors

Customer({required String email, String? phone, required String firstName, required String lastName, String? metadata})

Properties

email String
Customer's email address. Required
final
firstName String
Customer's first name. Required
final
hashCode int
The hash code for this object.
no setterinherited
lastName String
Customer's last name. Required
final
metadata String?
Additional metadata for the transaction. Optional
final
phone String?
Customer's phone number. Optional
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited