Customer class
Represents the customer making the payment.
Constructors
Properties
- email → String
-
Customer's email address.
Requiredfinal - firstName → String
-
Customer's first name.
Requiredfinal - hashCode → int
-
The hash code for this object.
no setterinherited
- lastName → String
-
Customer's last name.
Requiredfinal - metadata → String?
-
Additional metadata for the transaction.
Optionalfinal - phone → String?
-
Customer's phone number.
Optionalfinal - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited